==> dhall-json-1.7.12-160-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-json
version:              1.7.12
visibility:           public
id:                   dhall-json-1.7.12-9Lhc3XhxN3i88MRD3HPts8
key:                  dhall-json-1.7.12-9Lhc3XhxN3i88MRD3HPts8
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  d15496b8ec81efd06579cc6d0edd8aca
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Compat Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.12-9Lhc3XhxN3i88MRD3HPts8
depends:
    aeson-2.1.2.1-JZeWX2s1eQL7Ta3HF3w6fW
    aeson-pretty-0.8.10-LBJ177aL2uN3HrqwVlBpw9
    aeson-yaml-1.1.0.1-BvQvrXUU0YM7m7OYO9sH8P base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.3-2kjaaaE2WY7HTgm2a2p2DN exceptions-0.10.7
    filepath-1.4.300.1 lens-family-core-2.1.3-ATkyQy7CaRL9XkLMxregni
    optparse-applicative-0.18.1.0-3S7fKkQk1IxEovxwORLzkN
    prettyprinter-1.7.1-6IACTyjRPms8kgGy0SUdjP
    scientific-0.3.8.0-7SlgUkp6kxxBFUUY5SNCvh text-2.0.2
    unordered-containers-0.2.20.1-8SON4238u8N3rDHPceHjHx
    vector-0.13.2.0-JoP5POFPMLsLn1of7TvjGI

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-json-1.7.12-161-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-json
version:              1.7.12
visibility:           public
id:                   dhall-json-1.7.12-5L6VryabvYiK7VOAY8tada
key:                  dhall-json-1.7.12-5L6VryabvYiK7VOAY8tada
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  b5dbd6a44b2628eed1abaec83be252b3
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Compat Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.12-5L6VryabvYiK7VOAY8tada
depends:
    aeson-2.1.2.1-JZeWX2s1eQL7Ta3HF3w6fW
    aeson-pretty-0.8.10-LBJ177aL2uN3HrqwVlBpw9
    aeson-yaml-1.1.0.1-BvQvrXUU0YM7m7OYO9sH8P base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.3-KyvGbBRO1EJF4Ot9R06ZAG exceptions-0.10.7
    filepath-1.4.300.1 lens-family-core-2.1.3-ATkyQy7CaRL9XkLMxregni
    optparse-applicative-0.18.1.0-3S7fKkQk1IxEovxwORLzkN
    prettyprinter-1.7.1-6IACTyjRPms8kgGy0SUdjP
    scientific-0.3.8.0-7SlgUkp6kxxBFUUY5SNCvh text-2.0.2
    unordered-containers-0.2.20.1-8SON4238u8N3rDHPceHjHx
    vector-0.13.2.0-JoP5POFPMLsLn1of7TvjGI

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
